package com.bytesw.bytebot.controller;

import com.bytesw.bytebot.service.provider.TwilioService;
import com.bytesw.xdf.exception.NotFoundException;
import lombok.extern.log4j.Log4j2;
import org.apache.commons.lang.NullArgumentException;
import com.twilio.exception.AuthenticationException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.http.converter.HttpMessageNotReadableException;
import org.springframework.web.bind.annotation.*;
import com.google.gson.Gson;

import java.util.HashMap;
import java.util.Map;

@Log4j2
@RestController
@RequestMapping("/providers")
public class ProviderController {

    @Autowired
    private TwilioService twilioService;

    @Autowired
    private Gson gson;

    @RequestMapping(value="/twilio/messages/{sid_message}",method = {RequestMethod.DELETE})
    public ResponseEntity<String> deleteSensibleInfo(@PathVariable("sid_message") String sid_message, @RequestBody Map<String,Object> body){

        Map<String,Object> info = new HashMap<>();
        try{
            if(sid_message == null){
                throw new InvalidInput();
            }
            info = twilioService.generateInfo(sid_message,body);
        }
        catch(NotFoundException e){
            return new ResponseEntity<>(e.getMessage(),HttpStatus.NOT_FOUND);
        }catch (AuthenticationException e){
            return new ResponseEntity<>(e.getMessage(),HttpStatus.UNAUTHORIZED);
        }catch (InternalError e){
            return new ResponseEntity<>(e.getMessage(),HttpStatus.INTERNAL_SERVER_ERROR);
        }
        return  new ResponseEntity<>(gson.toJson(info), HttpStatus.OK);
    }

    @ResponseStatus(value=HttpStatus.INTERNAL_SERVER_ERROR, reason = "Input vacío")
    public class InvalidInput extends RuntimeException{

    }

}
